from setuptools import setup

setup(name='djan_dsnd_probability',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['djan_dsnd_probability'],
      author= 'Djan Magno',
      author_email= 'djan.magno@gmail.com',
      zip_safe=False)
